@@ -2,17 +2,18 @@ rawdata.prep <-
 function (cols.below1, cols.below2, cols.keep, colnames.new) {
 
   num_cols <- length(cols.below1)
-
+  num_colskeep <- length(cols.keep)
+  
   rawdata_nrow <- nrow(as.data.frame(cols.below1[1]))
-
-  newdata <- data.frame(matrix(ncol = 2, nrow = (rawdata_nrow*num_cols)))
+  
+  newdata <- data.frame(matrix(ncol = (num_colskeep+1), nrow = (rawdata_nrow*num_cols)))
   
   newdata_col <- 1
   i <- 0
   
   for (i in 1:num_cols) {
     newdata[newdata_col:rawdata_nrow,1] <- cols.below1[i]
-    newdata[newdata_col:rawdata_nrow,2] <- cols.keep
+    newdata[newdata_col:rawdata_nrow,2:((2+num_colskeep)-1)] <- cols.keep
     
     newdata_col <- rawdata_nrow+1
     rawdata_nrow <- rawdata_nrow+rawdata_nrow
@@ -21,17 +22,16 @@ function (cols.below1, cols.below2, cols.keep, colnames.new) {
   newdata1 <- newdata[,1]
   
   num_cols <- length(cols.below2)
-
+  
   rawdata_nrow <- nrow(as.data.frame(cols.below2[1]))
-
-  newdata <- data.frame(matrix(ncol = 2, nrow = (rawdata_nrow*num_cols)))
+  newdata <- data.frame(matrix(ncol = (num_colskeep+1), nrow = (rawdata_nrow*num_cols)))
   
   newdata_col <- 1
   i <- 0
   
   for (i in 1:num_cols) {
     newdata[newdata_col:rawdata_nrow,1] <- cols.below2[i]
-    newdata[newdata_col:rawdata_nrow,2] <- cols.keep
+    newdata[newdata_col:rawdata_nrow,2:((2+num_colskeep)-1)] <- cols.keep
     
     newdata_col <- rawdata_nrow+1
     rawdata_nrow <- rawdata_nrow+rawdata_nrow
@@ -44,5 +44,6 @@ function (cols.below1, cols.below2, cols.keep, colnames.new) {
   colnames(newdata_all) <- colnames.new 
   
   return(newdata_all)
+  
 }
 
