@@ -1,9 +1,8 @@
-tcmat.create <- 
-function (origins.id, origins.addr, 
-destinations.id, destinations.addr, 
-tc.type = "airline", tc.unit = "km", 
-or.addr.format = "stradr", de.addr.format = "stradr",
-tc.constant = 0, show_proc = FALSE) {
+tcmat.create <- function (origins.id, origins.addr, 
+                          destinations.id, destinations.addr, 
+                          tc.type = "airline", tc.unit = "km", 
+                          or.addr.format = "stradr", de.addr.format = "stradr",
+                          tc.constant = 0, query.delay = 0, show_proc = FALSE) {
   
   addr_formats <- c("stradr", "coords")
   if ((or.addr.format %in% addr_formats) == FALSE)
@@ -28,6 +27,7 @@ tc.constant = 0, show_proc = FALSE) {
   
   if (or.addr.format == "stradr") {
     
+
     if (show_proc == TRUE) {
       cat ("Geocoding origins ... ")
     }
@@ -39,6 +39,8 @@ tc.constant = 0, show_proc = FALSE) {
       
       coords <- geocode_OSM(as.character(origins.addr[i]))
       
+      Sys.sleep(query.delay)
+      
       coords_origins[i,1] <- as.character(origins.id[i])
       coords_origins[i,2] <- as.character(origins.addr[i])
       coords_origins[i,3] <- coords$coords[1]
@@ -69,12 +71,12 @@ tc.constant = 0, show_proc = FALSE) {
     coords_origins[,4] <- as.numeric(coords[,2])
     
     colnames(coords_origins) <- c("origins.id", "origins.addr", "origins.x_lon", "origins.y_lat")
-    
+
   }
   
   
   if (de.addr.format == "stradr") { 
-    
+
     if (show_proc == TRUE) { 
       cat ("Geocoding destinations ... ")
     }
@@ -86,6 +88,8 @@ tc.constant = 0, show_proc = FALSE) {
       
       coords <- geocode_OSM(as.character(destinations.addr[i]))
       
+      Sys.sleep(query.delay)
+      
       coords_destinations[i,1] <- as.character(destinations.id[i])
       coords_destinations[i,2] <- as.character(destinations.addr[i])
       coords_destinations[i,3] <- coords$coords[1]
@@ -93,13 +97,13 @@ tc.constant = 0, show_proc = FALSE) {
     }
     
     colnames(coords_destinations) <- c("destinations.id", "destinations.addr", "destinations.x_lon", "destinations.y_lat")
-    
+
     if (show_proc == TRUE) { cat("OK", "\n") }
     
   }
   
   if (de.addr.format == "coords") {
-    
+
     coords <- matrix(ncol = 2, nrow = length(destinations.id))
     
     for (i in 1:length(destinations.id)) {
@@ -115,19 +119,20 @@ tc.constant = 0, show_proc = FALSE) {
     coords_destinations[,4] <- as.numeric(coords[,2])
     
     colnames(coords_destinations) <- c("origins.id", "origins.addr", "origins.x_lon", "origins.y_lat")
-    
+
   }
   
   
+
   if (tc.type == "street") {
-    
+
     if (show_proc == TRUE) {
       cat ("Query of travel times ... ")
     }
     
     tc_single_list <- osrmTable(src = coords_origins[1:nrow(coords_origins),c("origins.id","origins.x_lon","origins.y_lat")],
                                 dst = coords_destinations[1:nrow(coords_destinations),c("destinations.id","destinations.x_lon","destinations.y_lat")])
-    
+
     if (show_proc == TRUE) {
       cat("OK", "\n")
       cat("\n")
@@ -151,7 +156,7 @@ tc.constant = 0, show_proc = FALSE) {
   }
   
   else {
-    
+
     if (show_proc == TRUE) {
       cat ("Calculating distances ... ")
     }
@@ -170,7 +175,7 @@ tc.constant = 0, show_proc = FALSE) {
   }
   
   tcmat$tc <- tcmat$tc+tc.constant
-  
+
   tc.mode <- list(tc.type = tc.type, tc.unit = tc.unit, tc.constant = tc.constant)
   
   invisible(list (tcmat = tcmat, coords_origins = coords_origins, coords_destinations = coords_destinations, tc.mode = tc.mode))
